@@ -1,14 +1,14 @@
 /*
  *  execute.c
  *
- *  $Id: execute.c,v 1.22 2006/01/20 15:58:34 source Exp $
+ *  $Id: execute.c,v 1.29 2009/09/09 12:10:58 source Exp $
  *
  *  Invoke a query
  *
  *  The iODBC driver manager.
  *
  *  Copyright (C) 1995 by Ke Jin <kejin@empress.com>
- *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
+ *  Copyright (C) 1996-2009 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
@@ -103,7 +103,7 @@ _iodbcdm_do_cursoropen (STMT_t * pstmt)
 
   retcode = _iodbcdm_NumResultCols ((SQLHSTMT) pstmt, &ncol);
 
-  if (retcode == SQL_SUCCESS || retcode == SQL_SUCCESS_WITH_INFO)
+  if (SQL_SUCCEEDED (retcode))
     {
       if (ncol)
 	{
@@ -119,6 +119,178 @@ _iodbcdm_do_cursoropen (STMT_t * pstmt)
 }
 
 
+#if (ODBCVER >= 0x0300)
+
+static SQLLEN
+GetElementSize (PPARM pparm)
+{
+  SQLLEN elementSize;
+
+  if (pparm->pm_c_type == SQL_C_CHAR || pparm->pm_c_type == SQL_C_BINARY)
+    elementSize = pparm->pm_cbValueMax == 0
+	? pparm->pm_precision : pparm->pm_cbValueMax;
+  else if (pparm->pm_c_type == SQL_C_WCHAR)
+    elementSize = pparm->pm_cbValueMax == 0
+	? pparm->pm_precision * sizeof(wchar_t) : pparm->pm_cbValueMax;
+  else				/* fixed length types */
+    elementSize = pparm->pm_size;
+
+  return elementSize;
+}
+
+
+static void 
+_Conv_W2A(wchar_t *wdata, SQLLEN *pInd, UDWORD size)
+{
+  char *data = (char *) wdata;
+
+
+  if (*pInd != SQL_NULL_DATA)
+    {
+      char *buf = (char *)dm_SQL_W2A ((SQLWCHAR *) wdata, (ssize_t)*pInd);
+
+      if (buf != NULL)
+	strcpy(data, buf);
+
+      MEM_FREE (buf);
+
+      if (pInd && *pInd != SQL_NTS)
+	*pInd /= sizeof (wchar_t);
+    }
+}
+
+
+static void 
+_Conv_A2W(char *data, SQLLEN *pInd, UDWORD size)
+{
+  wchar_t *wdata = (wchar_t *) data;
+
+
+  if (*pInd != SQL_NULL_DATA)
+    {
+      wchar_t *buf = (wchar_t *)dm_SQL_A2W ((SQLCHAR *) data, (ssize_t)*pInd);
+
+      if (buf != NULL)
+	WCSCPY (wdata, buf);
+
+      MEM_FREE (buf);
+    }
+}
+
+
+static SQLLEN
+_ConvParam (STMT_t *pstmt, PPARM pparm, SQLULEN row, BOOL bOutput)
+{
+  SQLLEN octetLen;
+  void *value;
+  SQLLEN *pInd = NULL;
+  SQLLEN elementSize = 0;
+
+  if (pparm->pm_c_type != SQL_C_WCHAR)
+    return 0;
+
+  elementSize = GetElementSize (pparm);
+
+  if (pstmt->bind_type)
+    {
+      /* row-wise binding of parameters in force */
+      if (pparm->pm_pOctetLength)
+	octetLen = *(SQLLEN *) ((char *) pparm->pm_pOctetLength
+	    + row * pstmt->bind_type);
+      else
+        octetLen = pparm->pm_size;
+
+      if (pparm->pm_pInd)
+        pInd = (SQLLEN *) ((char *) pparm->pm_pInd
+	        + row * pstmt->bind_type);
+    }
+  else
+    {
+      octetLen = pparm->pm_pOctetLength ? pparm->pm_pOctetLength[row] : pparm->pm_size;
+      if (pparm->pm_pInd)
+        pInd = pparm->pm_pInd + row;
+    }
+
+  if (!pInd || (pInd && *pInd == SQL_NULL_DATA))
+    return 0;
+
+  if (octetLen == SQL_DATA_AT_EXEC || octetLen <= SQL_LEN_DATA_AT_EXEC_OFFSET)
+    {
+      value = NULL;
+    }
+  else
+    value = pparm->pm_data;
+
+  if (value == NULL)
+    return 0;
+
+  if (pstmt->bind_type)
+    /* row-wise binding of parameters in force */
+    value = (char *) pparm->pm_data + row * pstmt->bind_type;
+  else
+    value = (char *) pparm->pm_data + row * elementSize;
+
+  if (bOutput)
+    _Conv_A2W(value, pInd, elementSize);
+  else
+    _Conv_W2A(value, pInd, elementSize);
+  return octetLen;
+
+}
+
+
+static SQLRETURN
+_SQLExecute_ConvParams (SQLHSTMT hstmt, BOOL bOutput)
+{
+  STMT (pstmt, hstmt);
+  CONN (pdbc, pstmt->hdbc);
+  ENVR (penv, pdbc->henv);
+  PPARM pparm;
+  int maxpar;
+  int i;
+  SQLULEN j;
+  SQLULEN cRows = pstmt->paramset_size;
+
+  if (penv->unicode_driver)
+    return SQL_SUCCESS;
+
+  if (cRows == 0)
+    cRows = 1;
+
+  maxpar = pstmt->st_nparam;
+
+  pparm = pstmt->st_pparam;
+  for (i = 0; i < maxpar; i++, pparm++)
+    {
+      if (pparm->pm_data == NULL)
+        continue;
+
+      if (bOutput && (pparm->pm_usage == SQL_PARAM_OUTPUT || pparm->pm_usage == SQL_PARAM_INPUT_OUTPUT))
+        {
+          if (pparm->pm_c_type_orig != SQL_C_WCHAR)
+            continue;
+
+          for (j = 0; j < cRows; j++)
+            _ConvParam(pstmt, pparm, j, bOutput);
+        }
+      else if (!bOutput && (pparm->pm_usage == SQL_PARAM_INPUT || pparm->pm_usage == SQL_PARAM_INPUT_OUTPUT))
+        {
+          if (pparm->pm_c_type != SQL_C_WCHAR)
+            continue;
+
+          for (j = 0; j < cRows; j++)
+            _ConvParam(pstmt, pparm, j, bOutput);
+
+          pparm->pm_c_type = SQL_C_CHAR;
+        }
+    } /* next column */
+
+  return SQL_SUCCESS;
+
+}
+
+#endif
+
 static SQLRETURN
 SQLExecute_Internal (SQLHSTMT hstmt)
 {
@@ -195,8 +367,10 @@ SQLExecute_Internal (SQLHSTMT hstmt)
       return SQL_ERROR;
     }
 
-  CALL_DRIVER (pstmt->hdbc, pstmt, retcode, hproc, en_Execute,
-      (pstmt->dhstmt));
+  if ((retcode = _SQLExecute_ConvParams(hstmt, FALSE)) != SQL_SUCCESS)
+    return retcode;
+  
+  CALL_DRIVER (pstmt->hdbc, pstmt, retcode, hproc, (pstmt->dhstmt));
 
   /* stmt state transition */
   if (pstmt->asyn_on == en_Execute)
@@ -216,6 +390,9 @@ SQLExecute_Internal (SQLHSTMT hstmt)
 	}
     }
 
+  if (retcode == SQL_SUCCESS || retcode == SQL_SUCCESS_WITH_INFO)
+    retcode = _SQLExecute_ConvParams(hstmt, TRUE);
+
   switch (pstmt->state)
     {
     case en_stmt_prepared:
@@ -355,17 +532,20 @@ SQLExecDirect_Internal (SQLHSTMT hstmt,
       if (waMode != 'W')
         {
         /* ansi=>unicode*/
-          _SqlStr = _iodbcdm_conv_param_A2W(pstmt, 0, (SQLCHAR *) szSqlStr, cbSqlStr);
+          _SqlStr = _iodbcdm_conv_var_A2W(pstmt, 0, (SQLCHAR *) szSqlStr, cbSqlStr);
         }
       else
         {
         /* unicode=>ansi*/
-          _SqlStr = _iodbcdm_conv_param_W2A(pstmt, 0, (SQLWCHAR *) szSqlStr, cbSqlStr);
+          _SqlStr = _iodbcdm_conv_var_W2A(pstmt, 0, (SQLWCHAR *) szSqlStr, cbSqlStr);
         }
       szSqlStr = _SqlStr;
       cbSqlStr = SQL_NTS;
     }
 
+  if ((retcode = _SQLExecute_ConvParams(hstmt, FALSE)) != SQL_SUCCESS)
+    return retcode;
+  
   CALL_UDRIVER(pstmt->hdbc, pstmt, retcode, hproc, penv->unicode_driver,
     en_ExecDirect, (
        pstmt->dhstmt,
@@ -374,13 +554,13 @@ SQLExecDirect_Internal (SQLHSTMT hstmt,
 
   if (hproc == SQL_NULL_HPROC)
     {
-      _iodbcdm_FreeStmtParams(pstmt);
+      _iodbcdm_FreeStmtVars(pstmt);
       PUSHSQLERR (pstmt->herr, en_IM001);
       return SQL_ERROR;
     }
 
   if (retcode != SQL_STILL_EXECUTING)
-    _iodbcdm_FreeStmtParams(pstmt);
+    _iodbcdm_FreeStmtVars(pstmt);
 
   /* stmt state transition */
   if (pstmt->asyn_on == en_ExecDirect)
@@ -400,6 +580,10 @@ SQLExecDirect_Internal (SQLHSTMT hstmt,
 	}
     }
 
+
+  if (retcode == SQL_SUCCESS || retcode == SQL_SUCCESS_WITH_INFO)
+    retcode = _SQLExecute_ConvParams(hstmt, TRUE);
+
   if (pstmt->state <= en_stmt_executed)
     {
       switch (retcode)
@@ -525,7 +709,7 @@ SQLPutData_Internal (
       return SQL_ERROR;
     }
 
-  CALL_DRIVER (pstmt->hdbc, pstmt, retcode, hproc, en_PutData,
+  CALL_DRIVER (pstmt->hdbc, pstmt, retcode, hproc, 
       (pstmt->dhstmt, rgbValue, cbValue));
 
   /* state transition */
@@ -643,8 +827,7 @@ SQLParamData_Internal (SQLHSTMT hstmt, SQLPOINTER * prgbValue)
       return SQL_ERROR;
     }
 
-  CALL_DRIVER (pstmt->hdbc, pstmt, retcode, hproc, en_ParamData,
-      (pstmt->dhstmt, prgbValue));
+  CALL_DRIVER (pstmt->hdbc, pstmt, retcode, hproc, (pstmt->dhstmt, prgbValue));
 
   /* state transition */
   if (pstmt->asyn_on == en_ParamData)
@@ -795,8 +978,7 @@ SQLNumParams_Internal (SQLHSTMT hstmt, SQLSMALLINT * pcpar)
       return SQL_ERROR;
     }
 
-  CALL_DRIVER (pstmt->hdbc, pstmt, retcode, hproc, en_NumParams,
-      (pstmt->dhstmt, pcpar));
+  CALL_DRIVER (pstmt->hdbc, pstmt, retcode, hproc, (pstmt->dhstmt, pcpar));
 
   /* state transition */
   if (pstmt->asyn_on == en_NumParams)
@@ -892,7 +1074,7 @@ SQLDescribeParam_Internal (
       return SQL_ERROR;
     }
 
-  CALL_DRIVER (pstmt->hdbc, pstmt, retcode, hproc, en_DescribeParam,
+  CALL_DRIVER (pstmt->hdbc, pstmt, retcode, hproc,
       (pstmt->dhstmt, ipar, pfSqlType, pcbColDef, pibScale, pfNullable));
 
   /*
