@@ -1,14 +1,14 @@
 /*
  *  henv.c
  *
- *  $Id: henv.c,v 1.21 2006/01/24 00:09:25 source Exp $
+ *  $Id: henv.c,v 1.23 2009/08/30 10:48:33 source Exp $
  *
  *  Environment object management functions
  *
  *  The iODBC driver manager.
  *
  *  Copyright (C) 1995 by Ke Jin <kejin@empress.com>
- *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
+ *  Copyright (C) 1996-2009 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
@@ -78,6 +78,7 @@
 
 #include <iodbc.h>
 
+#include <assert.h>
 #include <sql.h>
 #include <sqlext.h>
 
@@ -93,6 +94,7 @@
 /*
  *  Use static initializer where possible
  */
+
 #if defined (PTHREAD_MUTEX_INITIALIZER)
 SPINLOCK_DECLARE (iodbcdm_global_lock) = PTHREAD_MUTEX_INITIALIZER;
 #else
@@ -156,6 +158,9 @@ SQLAllocEnv_Internal (SQLHENV * phenv, int odbc_ver)
   genv->herr = SQL_NULL_HERR;	/* err list          */
 #if (ODBCVER >= 0x300)
   genv->odbc_ver = odbc_ver;
+  genv->connection_pooling = _iodbcdm_attr_connection_pooling;
+  genv->cp_match = SQL_CP_MATCH_DEFAULT;
+  genv->pdbc_pool = NULL;
 #endif
   genv->err_rec = 0;
 
@@ -199,6 +204,8 @@ SQLAllocEnv (SQLHENV * phenv)
 }
 
 
+extern void _iodbcdm_pool_drop_conn (HDBC hdbc, HDBC hdbc_prev);
+
 SQLRETURN
 SQLFreeEnv_Internal (SQLHENV henv)
 {
@@ -217,6 +224,12 @@ SQLFreeEnv_Internal (SQLHENV henv)
       return SQL_ERROR;
     }
 
+#if (ODBCVER >= 0x300)
+  /* Drop connections from the pool */
+  while (genv->pdbc_pool != NULL)
+    _iodbcdm_pool_drop_conn (genv->pdbc_pool, NULL);
+#endif
+
   /*
    *  Invalidate this handle
    */
