@@ -1,14 +1,14 @@
 /*
  *  herr.c
  *
- *  $Id: herr.c,v 1.30 2007/10/07 14:09:10 source Exp $
+ *  $Id: herr.c,v 1.32 2009/08/30 10:48:33 source Exp $
  *
  *  Error stack management functions
  *
  *  The iODBC driver manager.
  *
  *  Copyright (C) 1995 by Ke Jin <kejin@empress.com>
- *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
+ *  Copyright (C) 1996-2009 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
@@ -363,13 +363,13 @@ _iodbcdm_sqlerror (
 
   if (herr == SQL_NULL_HERR)	/* no err on drv mng */
     {
-      if (((DBC_t *)hdbc)->genv)
-        odbc_ver = ((GENV_t *) ((DBC_t *)hdbc)->genv)->odbc_ver;
+      if (thdbc && ((DBC_t *)thdbc)->genv)
+        odbc_ver = ((GENV_t *) ((DBC_t *)thdbc)->genv)->odbc_ver;
 
-      if (((DBC_t *)hdbc)->henv)
+      if (thdbc && ((DBC_t *)thdbc)->henv)
         {
-          unicode_driver = ((ENV_t *) ((DBC_t *)hdbc)->henv)->unicode_driver;
-          dodbc_ver = ((ENV_t *) ((DBC_t *)hdbc)->henv)->dodbc_ver;
+          unicode_driver = ((ENV_t *) ((DBC_t *)thdbc)->henv)->unicode_driver;
+          dodbc_ver = ((ENV_t *) ((DBC_t *)thdbc)->henv)->dodbc_ver;
         }
 
       /* call driver */
@@ -939,13 +939,13 @@ SQLGetDiagRec_Internal (
 	}
       RecNumber -= nRecs;
 
-      if (((DBC_t *)hdbc)->henv)
+      if (hdbc && ((DBC_t *)hdbc)->henv)
         {
           unicode_driver = ((ENV_t *) ((DBC_t *)hdbc)->henv)->unicode_driver;
           dodbc_ver = ((ENV_t *) ((DBC_t *)hdbc)->henv)->dodbc_ver;
         }
 
-      if (((DBC_t *)hdbc)->genv)
+      if (hdbc && ((DBC_t *)hdbc)->genv)
         odbc_ver = ((GENV_t *) ((DBC_t *)hdbc)->genv)->odbc_ver;
 
       if ((unicode_driver && waMode != 'W') 
