@@ -1,14 +1,14 @@
 /*
  *  info.c
  *
- *  $Id: info.c,v 1.32 2006/01/20 15:58:34 source Exp $
+ *  $Id: info.c,v 1.38 2009/08/30 11:00:08 source Exp $
  *
  *  Information functions
  *
  *  The iODBC driver manager.
  *
  *  Copyright (C) 1995 by Ke Jin <kejin@empress.com>
- *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
+ *  Copyright (C) 1996-2009 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
@@ -402,7 +402,7 @@ SQLDataSourcesW (
 	_Desc, cbDescMax * UTF8_MAX_CHAR_LEN, pcbDesc, 
 	'W');
 
-  if (retcode == SQL_SUCCESS || retcode == SQL_SUCCESS_WITH_INFO)
+  if (SQL_SUCCEEDED (retcode))
     {
       dm_StrCopyOut2_U8toW (_DSN, szDSN, cbDSNMax, pcbDSN);
       dm_StrCopyOut2_U8toW (_Desc, szDesc, cbDescMax, pcbDesc);
@@ -690,7 +690,7 @@ SQLDriversW (SQLHENV henv,
 	_Attrs, cbDrvAttrMax * UTF8_MAX_CHAR_LEN, pcbDrvAttr, 
 	'W');
 
-  if (retcode == SQL_SUCCESS || retcode == SQL_SUCCESS_WITH_INFO)
+  if (SQL_SUCCEEDED (retcode))
     {
       dm_StrCopyOut2_U8toW (_Driver, szDrvDesc, cbDrvDescMax, pcbDrvDesc);
       dm_StrCopyOut2_U8toW (_Attrs, szDrvAttr, cbDrvAttrMax, pcbDrvAttr);
@@ -864,7 +864,7 @@ SQLGetInfo_Internal (
       break;
 
     default:
-      /* NOTE : this was before the switch, just move here to let some informations going through */
+      /* NOTE : this was before the switch, just move here to let some information going through */
       if (pdbc->state == en_dbc_allocated || pdbc->state == en_dbc_needdata)
 	{
 	  PUSHSQLERR (pdbc->herr, en_08003);
@@ -1022,8 +1022,8 @@ SQLGetInfo_Internal (
 
     }
   else if (rgbInfoValue 
-          && (retcode == SQL_SUCCESS || retcode == SQL_SUCCESS_WITH_INFO)
-          &&  ((penv->unicode_driver && waMode != 'W') 
+          && SQL_SUCCEEDED (retcode)
+          && ((penv->unicode_driver && waMode != 'W') 
               || (!penv->unicode_driver && waMode == 'W')))
     {
       switch(fInfoType)
@@ -1308,8 +1308,7 @@ SQLGetFunctions_Internal (
 
   if (hproc != SQL_NULL_HPROC)
     {
-      CALL_DRIVER (hdbc, pdbc, retcode, hproc, en_GetFunctions,
-	  (pdbc->dhdbc, fFunc, pfExists));
+      CALL_DRIVER (hdbc, pdbc, retcode, hproc, (pdbc->dhdbc, fFunc, pfExists));
 
       return retcode;
     }
