@@ -1,13 +1,13 @@
 /*
  *  ColAttribute.c
  *
- *  $Id: ColAttribute.c,v 1.7 2006/01/20 15:58:35 source Exp $
+ *  $Id: ColAttribute.c,v 1.9 2009/08/30 11:00:08 source Exp $
  *
  *  SQLColAttribute trace functions
  *
  *  The iODBC driver manager.
  *
- *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
+ *  Copyright (C) 1996-2009 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
@@ -301,7 +301,7 @@ _trace_colattr3_data (
 	}
       else if (type == 7)	/* updatable */
 	{
-	  char *ptr = "unknown ubdatable type";
+	  char *ptr = "unknown updatable type";
 
 	  switch (*NumericAttributePtr)
 	    {
