@@ -1,11 +1,11 @@
 /*
  *  translator.c
  *
- *  $Id: translatorchooser.c,v 1.7 2007/02/02 11:58:14 source Exp $
+ *  $Id: translatorchooser.c,v 1.10 2009/08/30 11:31:14 source Exp $
  *
  *  The iODBC driver manager.
  *
- *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
+ *  Copyright (C) 1996-2009 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
@@ -266,106 +266,66 @@ addtranslators_to_list (GtkWidget *widget, GtkWidget *dlg)
 void
 create_translatorchooser (HWND hwnd, TTRANSLATORCHOOSER *choose_t)
 {
-  GtkWidget *translatorchooser, *dialog_vbox1, *fixed1, *l_diz,
-      *scrolledwindow1;
-  GtkWidget *clist1, *l_name, *l_file, *l_date, *l_size, *dialog_action_area1;
-  GtkWidget *hbuttonbox1, *b_finish, *b_cancel, *pixmap1;
-  guint b_finish_key, b_cancel_key;
   GdkPixmap *pixmap;
   GdkBitmap *mask;
   GtkStyle *style;
-  GtkAccelGroup *accel_group;
+
+  GtkWidget *translatorchooser;
+  GtkWidget *vbox41;
+  GtkWidget *hbox57;
+  GtkWidget *frame97;
+  GtkWidget *alignment81;
+  GtkWidget *pixmap1;
+  GtkWidget *frame98;
+  GtkWidget *alignment82;
+  GtkWidget *scrolledwindow21;
+  GtkWidget *clist1;
+  GtkWidget *label158;
+  GtkWidget *label159;
+  GtkWidget *label160;
+  GtkWidget *label161;
+  GtkWidget *label162;
+  GtkWidget *hbuttonbox3;
+  GtkWidget *b_finish;
+  GtkWidget *b_cancel;
 
   if (hwnd == NULL || !GTK_IS_WIDGET (hwnd))
     return;
 
-  accel_group = gtk_accel_group_new ();
-
   translatorchooser = gtk_dialog_new ();
-  gtk_object_set_data (GTK_OBJECT (translatorchooser), "translatorchooser",
-      translatorchooser);
-  gtk_window_set_title (GTK_WINDOW (translatorchooser),
-      "Choose a Translator");
-  gtk_window_set_position (GTK_WINDOW (translatorchooser),
-      GTK_WIN_POS_CENTER);
+  gtk_widget_set_name (translatorchooser, "translatorchooser");
+  gtk_widget_set_size_request (translatorchooser, 515, 335);
+  gtk_window_set_title (GTK_WINDOW (translatorchooser), _("Choose a Translator"));
+  gtk_window_set_position (GTK_WINDOW (translatorchooser), GTK_WIN_POS_CENTER_ON_PARENT);
   gtk_window_set_modal (GTK_WINDOW (translatorchooser), TRUE);
-  gtk_window_set_policy (GTK_WINDOW (translatorchooser), FALSE, FALSE, FALSE);
+  gtk_window_set_default_size (GTK_WINDOW (translatorchooser), 600, 450);
+  gtk_window_set_type_hint (GTK_WINDOW (translatorchooser), GDK_WINDOW_TYPE_HINT_DIALOG);
 
 #if GTK_CHECK_VERSION(2,0,0)
   gtk_widget_show (translatorchooser);
 #endif
 
-  dialog_vbox1 = GTK_DIALOG (translatorchooser)->vbox;
-  gtk_object_set_data (GTK_OBJECT (translatorchooser), "dialog_vbox1",
-      dialog_vbox1);
-  gtk_widget_show (dialog_vbox1);
+  vbox41 = GTK_DIALOG (translatorchooser)->vbox;
+  gtk_widget_set_name (vbox41, "vbox41");
+  gtk_widget_show (vbox41);
 
-  fixed1 = gtk_fixed_new ();
-  gtk_widget_ref (fixed1);
-  gtk_object_set_data_full (GTK_OBJECT (translatorchooser), "fixed1", fixed1,
-      (GtkDestroyNotify) gtk_widget_unref);
-  gtk_widget_show (fixed1);
-  gtk_box_pack_start (GTK_BOX (dialog_vbox1), fixed1, TRUE, TRUE, 0);
-  gtk_container_set_border_width (GTK_CONTAINER (fixed1), 6);
+  hbox57 = gtk_hbox_new (FALSE, 0);
+  gtk_widget_set_name (hbox57, "hbox57");
+  gtk_widget_show (hbox57);
+  gtk_box_pack_start (GTK_BOX (vbox41), hbox57, TRUE, TRUE, 0);
 
-  l_diz = gtk_label_new ("Select which ODBC Translator you want to use.");
-  gtk_widget_ref (l_diz);
-  gtk_object_set_data_full (GTK_OBJECT (translatorchooser), "l_diz", l_diz,
-      (GtkDestroyNotify) gtk_widget_unref);
-  gtk_widget_show (l_diz);
-  gtk_fixed_put (GTK_FIXED (fixed1), l_diz, 168, 16);
-  gtk_widget_set_uposition (l_diz, 168, 16);
-  gtk_widget_set_usize (l_diz, 325, 16);
-  gtk_label_set_justify (GTK_LABEL (l_diz), GTK_JUSTIFY_LEFT);
+  frame97 = gtk_frame_new (NULL);
+  gtk_widget_set_name (frame97, "frame97");
+  gtk_widget_show (frame97);
+  gtk_box_pack_start (GTK_BOX (hbox57), frame97, FALSE, TRUE, 0);
+  gtk_container_set_border_width (GTK_CONTAINER (frame97), 10);
+  gtk_frame_set_shadow_type (GTK_FRAME (frame97), GTK_SHADOW_NONE);
 
-  scrolledwindow1 = gtk_scrolled_window_new (NULL, NULL);
-  gtk_widget_ref (scrolledwindow1);
-  gtk_object_set_data_full (GTK_OBJECT (translatorchooser), "scrolledwindow1",
-      scrolledwindow1, (GtkDestroyNotify) gtk_widget_unref);
-  gtk_widget_show (scrolledwindow1);
-  gtk_fixed_put (GTK_FIXED (fixed1), scrolledwindow1, 168, 32);
-  gtk_widget_set_uposition (scrolledwindow1, 168, 32);
-  gtk_widget_set_usize (scrolledwindow1, 320, 248);
-
-  clist1 = gtk_clist_new (4);
-  gtk_widget_ref (clist1);
-  gtk_object_set_data_full (GTK_OBJECT (translatorchooser), "clist1", clist1,
-      (GtkDestroyNotify) gtk_widget_unref);
-  gtk_widget_show (clist1);
-  gtk_container_add (GTK_CONTAINER (scrolledwindow1), clist1);
-  gtk_clist_set_column_width (GTK_CLIST (clist1), 0, 165);
-  gtk_clist_set_column_width (GTK_CLIST (clist1), 1, 118);
-  gtk_clist_set_column_width (GTK_CLIST (clist1), 2, 80);
-  gtk_clist_set_column_width (GTK_CLIST (clist1), 3, 80);
-  gtk_clist_column_titles_show (GTK_CLIST (clist1));
-
-  l_name = gtk_label_new (szDriverColumnNames[0]);
-  gtk_widget_ref (l_name);
-  gtk_object_set_data_full (GTK_OBJECT (translatorchooser), "l_name", l_name,
-      (GtkDestroyNotify) gtk_widget_unref);
-  gtk_widget_show (l_name);
-  gtk_clist_set_column_widget (GTK_CLIST (clist1), 0, l_name);
-
-  l_file = gtk_label_new (szDriverColumnNames[1]);
-  gtk_widget_ref (l_file);
-  gtk_object_set_data_full (GTK_OBJECT (translatorchooser), "l_file", l_file,
-      (GtkDestroyNotify) gtk_widget_unref);
-  gtk_widget_show (l_file);
-  gtk_clist_set_column_widget (GTK_CLIST (clist1), 1, l_file);
-
-  l_date = gtk_label_new (szDriverColumnNames[2]);
-  gtk_widget_ref (l_date);
-  gtk_object_set_data_full (GTK_OBJECT (translatorchooser), "l_date", l_date,
-      (GtkDestroyNotify) gtk_widget_unref);
-  gtk_widget_show (l_date);
-  gtk_clist_set_column_widget (GTK_CLIST (clist1), 2, l_date);
-
-  l_size = gtk_label_new (szDriverColumnNames[3]);
-  gtk_widget_ref (l_size);
-  gtk_object_set_data_full (GTK_OBJECT (translatorchooser), "l_size", l_size,
-      (GtkDestroyNotify) gtk_widget_unref);
-  gtk_widget_show (l_size);
-  gtk_clist_set_column_widget (GTK_CLIST (clist1), 3, l_size);
+  alignment81 = gtk_alignment_new (0.5, 0.5, 1, 1);
+  gtk_widget_set_name (alignment81, "alignment81");
+  gtk_widget_show (alignment81);
+  gtk_container_add (GTK_CONTAINER (frame97), alignment81);
+  gtk_widget_set_size_request (alignment81, 140, -1);
 
 #if GTK_CHECK_VERSION(2,0,0)
   style = gtk_widget_get_style (translatorchooser);
@@ -378,59 +338,104 @@ create_translatorchooser (HWND hwnd, TTRANSLATORCHOOSER *choose_t)
       gdk_pixmap_create_from_xpm_d (GTK_WIDGET (hwnd)->window, &mask,
       &style->bg[GTK_STATE_NORMAL], (gchar **) img_xpm);
 #endif
-
   pixmap1 = gtk_pixmap_new (pixmap, mask);
-  gtk_widget_ref (pixmap1);
-  gtk_object_set_data_full (GTK_OBJECT (translatorchooser), "pixmap1",
-      pixmap1, (GtkDestroyNotify) gtk_widget_unref);
+  gtk_widget_set_name (pixmap1, "pixmap1");
   gtk_widget_show (pixmap1);
-  gtk_fixed_put (GTK_FIXED (fixed1), pixmap1, 16, 16);
-  gtk_widget_set_uposition (pixmap1, 16, 16);
-  gtk_widget_set_usize (pixmap1, 136, 264);
+  gtk_container_add (GTK_CONTAINER (alignment81), pixmap1);
 
-  dialog_action_area1 = GTK_DIALOG (translatorchooser)->action_area;
-  gtk_object_set_data (GTK_OBJECT (translatorchooser), "dialog_action_area1",
-      dialog_action_area1);
-  gtk_widget_show (dialog_action_area1);
-  gtk_container_set_border_width (GTK_CONTAINER (dialog_action_area1), 5);
+  frame98 = gtk_frame_new (NULL);
+  gtk_widget_set_name (frame98, "frame98");
+  gtk_widget_show (frame98);
+  gtk_box_pack_start (GTK_BOX (hbox57), frame98, TRUE, TRUE, 0);
+  gtk_frame_set_shadow_type (GTK_FRAME (frame98), GTK_SHADOW_NONE);
 
-  hbuttonbox1 = gtk_hbutton_box_new ();
-  gtk_widget_ref (hbuttonbox1);
-  gtk_object_set_data_full (GTK_OBJECT (translatorchooser), "hbuttonbox1",
-      hbuttonbox1, (GtkDestroyNotify) gtk_widget_unref);
-  gtk_widget_show (hbuttonbox1);
-  gtk_box_pack_start (GTK_BOX (dialog_action_area1), hbuttonbox1, TRUE, TRUE,
-      0);
-  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox1), GTK_BUTTONBOX_END);
-  gtk_button_box_set_spacing (GTK_BUTTON_BOX (hbuttonbox1), 10);
+  alignment82 = gtk_alignment_new (0.5, 0.5, 1, 1);
+  gtk_widget_set_name (alignment82, "alignment82");
+  gtk_widget_show (alignment82);
+  gtk_container_add (GTK_CONTAINER (frame98), alignment82);
+  gtk_alignment_set_padding (GTK_ALIGNMENT (alignment82), 0, 10, 0, 0);
 
-  b_finish = gtk_button_new_with_label ("");
-  b_finish_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (b_finish)->child),
-      "_Finish");
-  gtk_widget_add_accelerator (b_finish, "clicked", accel_group,
-      b_finish_key, GDK_MOD1_MASK, 0);
-  gtk_widget_ref (b_finish);
-  gtk_object_set_data_full (GTK_OBJECT (translatorchooser), "b_finish",
-      b_finish, (GtkDestroyNotify) gtk_widget_unref);
+  scrolledwindow21 = gtk_scrolled_window_new (NULL, NULL);
+  gtk_widget_set_name (scrolledwindow21, "scrolledwindow21");
+  gtk_widget_show (scrolledwindow21);
+  gtk_container_add (GTK_CONTAINER (alignment82), scrolledwindow21);
+
+  clist1 = gtk_clist_new (4);
+  gtk_widget_set_name (clist1, "clist1");
+  gtk_widget_show (clist1);
+  gtk_container_add (GTK_CONTAINER (scrolledwindow21), clist1);
+  gtk_clist_set_column_width (GTK_CLIST (clist1), 0, 165);
+  gtk_clist_set_column_width (GTK_CLIST (clist1), 1, 118);
+  gtk_clist_set_column_width (GTK_CLIST (clist1), 2, 80);
+  gtk_clist_set_column_width (GTK_CLIST (clist1), 3, 80);
+  gtk_clist_column_titles_show (GTK_CLIST (clist1));
+
+  label158 = gtk_label_new (_("Name"));
+  gtk_widget_set_name (label158, "label158");
+  gtk_widget_show (label158);
+  gtk_clist_set_column_widget (GTK_CLIST (clist1), 0, label158);
+  gtk_widget_set_size_request (label158, 165, -1);
+
+  label159 = gtk_label_new (_("File"));
+  gtk_widget_set_name (label159, "label159");
+  gtk_widget_show (label159);
+  gtk_clist_set_column_widget (GTK_CLIST (clist1), 1, label159);
+  gtk_widget_set_size_request (label159, 118, -1);
+
+  label160 = gtk_label_new (_("Date"));
+  gtk_widget_set_name (label160, "label160");
+  gtk_widget_show (label160);
+  gtk_clist_set_column_widget (GTK_CLIST (clist1), 2, label160);
+  gtk_widget_set_size_request (label160, 80, -1);
+
+  label161 = gtk_label_new (_("Size"));
+  gtk_widget_set_name (label161, "label161");
+  gtk_widget_show (label161);
+  gtk_clist_set_column_widget (GTK_CLIST (clist1), 3, label161);
+  gtk_widget_set_size_request (label161, 80, -1);
+
+  label162 = gtk_label_new (_("Select which ODBC Translator you want to use"));
+  gtk_widget_set_name (label162, "label162");
+  gtk_widget_show (label162);
+  gtk_frame_set_label_widget (GTK_FRAME (frame98), label162);
+  gtk_label_set_use_markup (GTK_LABEL (label162), TRUE);
+
+  hbuttonbox3 = GTK_DIALOG (translatorchooser)->action_area;
+  gtk_widget_set_name (hbuttonbox3, "hbuttonbox3");
+  gtk_widget_show (hbuttonbox3);
+  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox3), GTK_BUTTONBOX_END);
+
+  b_finish = gtk_button_new_from_stock ("gtk-ok");
+  gtk_widget_set_name (b_finish, "b_finish");
   gtk_widget_show (b_finish);
-  gtk_container_add (GTK_CONTAINER (hbuttonbox1), b_finish);
+  gtk_dialog_add_action_widget (GTK_DIALOG (translatorchooser), b_finish, GTK_RESPONSE_OK);
   GTK_WIDGET_SET_FLAGS (b_finish, GTK_CAN_DEFAULT);
-  gtk_widget_add_accelerator (b_finish, "clicked", accel_group,
-      'F', GDK_MOD1_MASK, GTK_ACCEL_VISIBLE);
 
-  b_cancel = gtk_button_new_with_label ("");
-  b_cancel_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (b_cancel)->child),
-      "_Cancel");
-  gtk_widget_add_accelerator (b_cancel, "clicked", accel_group,
-      b_cancel_key, GDK_MOD1_MASK, 0);
-  gtk_widget_ref (b_cancel);
-  gtk_object_set_data_full (GTK_OBJECT (translatorchooser), "b_cancel",
-      b_cancel, (GtkDestroyNotify) gtk_widget_unref);
+  b_cancel = gtk_button_new_from_stock ("gtk-cancel");
+  gtk_widget_set_name (b_cancel, "b_cancel");
   gtk_widget_show (b_cancel);
-  gtk_container_add (GTK_CONTAINER (hbuttonbox1), b_cancel);
+  gtk_dialog_add_action_widget (GTK_DIALOG (translatorchooser), b_cancel, GTK_RESPONSE_CANCEL);
   GTK_WIDGET_SET_FLAGS (b_cancel, GTK_CAN_DEFAULT);
-  gtk_widget_add_accelerator (b_cancel, "clicked", accel_group,
-      'C', GDK_MOD1_MASK, GTK_ACCEL_VISIBLE);
+
+  /* Store pointers to all widgets, for use by lookup_widget(). */
+  GLADE_HOOKUP_OBJECT_NO_REF (translatorchooser, translatorchooser, "translatorchooser");
+  GLADE_HOOKUP_OBJECT_NO_REF (translatorchooser, vbox41, "vbox41");
+  GLADE_HOOKUP_OBJECT (translatorchooser, hbox57, "hbox57");
+  GLADE_HOOKUP_OBJECT (translatorchooser, frame97, "frame97");
+  GLADE_HOOKUP_OBJECT (translatorchooser, alignment81, "alignment81");
+  GLADE_HOOKUP_OBJECT (translatorchooser, pixmap1, "pixmap1");
+  GLADE_HOOKUP_OBJECT (translatorchooser, frame98, "frame98");
+  GLADE_HOOKUP_OBJECT (translatorchooser, alignment82, "alignment82");
+  GLADE_HOOKUP_OBJECT (translatorchooser, scrolledwindow21, "scrolledwindow21");
+  GLADE_HOOKUP_OBJECT (translatorchooser, clist1, "clist1");
+  GLADE_HOOKUP_OBJECT (translatorchooser, label158, "label158");
+  GLADE_HOOKUP_OBJECT (translatorchooser, label159, "label159");
+  GLADE_HOOKUP_OBJECT (translatorchooser, label160, "label160");
+  GLADE_HOOKUP_OBJECT (translatorchooser, label161, "label161");
+  GLADE_HOOKUP_OBJECT (translatorchooser, label162, "label162");
+  GLADE_HOOKUP_OBJECT_NO_REF (translatorchooser, hbuttonbox3, "hbuttonbox3");
+  GLADE_HOOKUP_OBJECT (translatorchooser, b_finish, "b_finish");
+  GLADE_HOOKUP_OBJECT (translatorchooser, b_cancel, "b_cancel");
 
   /* Ok button events */
   gtk_signal_connect (GTK_OBJECT (b_finish), "clicked",
@@ -447,8 +452,6 @@ create_translatorchooser (HWND hwnd, TTRANSLATORCHOOSER *choose_t)
   gtk_signal_connect (GTK_OBJECT (clist1), "select_row",
       GTK_SIGNAL_FUNC (translator_list_select), choose_t);
 
-  gtk_window_add_accel_group (GTK_WINDOW (translatorchooser), accel_group);
-
   addtranslators_to_list (clist1, translatorchooser);
 
   choose_t->translatorlist = clist1;
