@@ -1,13 +1,13 @@
 /*
  *  SQLManageDataSource.c
  *
- *  $Id: SQLManageDataSource.c,v 1.13 2006/01/20 15:58:35 source Exp $
+ *  $Id: SQLManageDataSource.c,v 1.15 2009/09/10 13:04:55 source Exp $
  *
  *  Add, modify or delete datasources
  *
  *  The iODBC driver manager.
  *
- *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
+ *  Copyright (C) 1996-2009 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
@@ -134,7 +134,7 @@ ManageDataSources (HWND hwndParent)
     }
 
 #else
-  CALL_ADMIN_DIALBOX ("libiodbcadm.so");
+  CALL_ADMIN_DIALBOX ("libiodbcadm.so.2");
 #endif
 
   return retcode;
