@@ -1,13 +1,13 @@
 /*
  *  unicode.c
  *
- *  $Id: unicode.c,v 1.3 2007/10/07 12:32:08 source Exp $
+ *  $Id: unicode.c,v 1.5 2009/09/01 23:26:17 source Exp $
  *
  *  ODBC unicode functions
  *
  *  The iODBC driver manager.
  *
- *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
+ *  Copyright (C) 1996-2009 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
@@ -230,7 +230,7 @@ towlower (wchar_t wc)
 
 
 #if !defined(HAVE_WCSNCASECMP)
-int wcsncasecmp (wchar_t* s1, wchar_t* s2, size_t n)
+int wcsncasecmp (const wchar_t* s1, const wchar_t* s2, size_t n)
 {
   wchar_t c1, c2;
   
