@@ -4,7 +4,7 @@
 #
 #  The iODBC driver manager.
 #
-#  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
+#  Copyright (C) 1996-2009 by OpenLink Software <iodbc@openlinksw.com>
 #  All Rights Reserved.
 #
 #  This software is released under the terms of either of the following
@@ -75,7 +75,7 @@
 #
 #  Installation PATHS
 #
-PREFIX="/usr/local/iODBC"
+PREFIX="$DESTDIR/usr/local/iODBC"
 ODBC_FW="/Library/Frameworks/iODBC.framework"
 INST_FW="/Library/Frameworks/iODBCinst.framework"
 
